@@ -78,7 +78,7 @@ class Entity(object):
                 g.bind(prefix, ns)
             for s,p,o in g_m.triples((None, None, None)):
                 g.add((s, p, o))
-        return g.serialize(format=format, encoding="utf-8")
+        return g.serialize(format=format, encoding="utf-8") + u"\n"
 
     def from_string(self, root_uri, rdfstring, format="xml"):
         t = TextInputSource(rdfstring)
