@@ -97,7 +97,6 @@ class RDFobject(object):
     def add_triple(self, predicate, objectRef):
         if not isinstance(objectRef, URIRef) and not isinstance(objectRef, Literal):
             objectRef = self.urihelper.parse_uri(objectRef, return_Literal_not_Exception=True)
-        
         predicate_uri = self.urihelper.parse_uri(predicate)
         
         if (predicate_uri, objectRef) not in self.triples:
@@ -212,10 +211,6 @@ class RDFobject(object):
         return self.to_string('xml')
     
     def to_string(self, format="xml"):
-#        if self.altered or self._cached == False:
-#            self.altered = False
-#            self._cached = self.get_graph()
-#        return self._cached.serialize(format=format, encoding="utf-8")
-        return self.get_graph().serialize(format=format, encoding="utf-8")
+        return self.get_graph().serialize(format=format, encoding="utf-8")+u"\n"
         
 
